KEY_ID = "ID"
KEY_AUTHOR = "author"
KEY_MONTH = "month"
KEY_TITLE = "title"
KEY_PAGES = "pages"
KEY_YEAR = "year"
KEY_EPRINT = "eprint"
KEY_ARCHIVE = "archiveprefix"
KEY_CATEGORY = "primaryclass"
KEY_ENTRYTYPE = "ENTRYTYPE"
KEYS_JOURNAL = ["journal", "journaltitle"]
KEY_BOOKTITLE = "booktitle"
KEY_EDITOR = "editor"
